from setuptools import setup

setup(name = 'mlb_distributions',
      version = '0.1',
      description = 'Gaussian distributions',
      packages = ['mlb_distributions'],
      author = 'Montse Llos',
      author_email = 'montse.llos@gmail.com',
      zip_safe=False)
